%define major		2.10
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%global _vpath_srcdir Release

Name:		cpprest
Version:	2.10.17
Release:	%mkrel 1
Summary:	C++ REST library
License:	MIT
Group:		System/Libraries
URL:		https://github.com/Microsoft/cpprestsdk
Source0:	https://github.com/Microsoft/cpprestsdk/archive/%{version}/cpprestsdk-%{version}.tar.gz
BuildRequires:	cmake
BuildRequires:	gcc-c++
BuildRequires:	boost-devel
BuildRequires:	cmake(websocketpp)
BuildRequires:	pkgconfig(libbrotlidec)
BuildRequires:	pkgconfig(libbrotlienc)
BuildRequires:	pkgconfig(openssl)

%description
The C++ REST SDK is a Microsoft project for cloud-based client-server
communication in native code using a modern asynchronous C++ API design. This
project aims to help C++ developers connect to and interact with services.

Also known as Casablanca.

#------------------------------------------------

%package -n	%{libname}
Summary:	C++ Rest library
Group:		System/Libraries

%description -n	%{libname}
The C++ REST SDK is a Microsoft project for cloud-based client-server
communication in native code using a modern asynchronous C++ API design. This
project aims to help C++ developers connect to and interact with services.

#------------------------------------------------

%package -n	%{develname}
Summary:	Development package for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
The C++ REST SDK is a Microsoft project for cloud-based client-server
communication in native code using a modern asynchronous C++ API design. This
project aims to help C++ developers connect to and interact with services.

Header files for development with %{name}.

#------------------------------------------------

%prep
%setup -q -n cpprestsdk-%{version}
%autopatch -p1

# Remove bundled sources of websocketpp
rm -r Release/libs
# Remove file ThirdPartyNotices.txt, which is associated to websocketpp
rm ThirdPartyNotices.txt

%build
%cmake \
	-DCMAKE_BUILD_TYPE=Release \
	-DCPPREST_EXPORT_DIR=cmake/cpprestsdk \
	-DWEBSOCKETPP_INCLUDE_DIR=%{_includedir}/websocketpp \
	-DWERROR=OFF \
	-DCPPREST_EXCLUDE_BROTLI=OFF

%cmake_build

%install
%cmake_install

# create a pkgconfig file
install -d %{buildroot}%{_libdir}/pkgconfig
cat << EOF > %{buildroot}%{_libdir}/pkgconfig/%{name}.pc
prefix=%{_prefix}
exec_prefix=%{_prefix}
libdir=%{_libdir}
includedir=%{_includedir}

Name: %{name}
Description: cloud-based client-server communication
URL: %{url}
Version: %{version}
Libs: -L%{_libdir} -lcpprest
Cflags: -I%{_includedir}/cpprest -I%{_includedir}/pplx
EOF

%files -n %{libname}
%license license.txt
%doc CONTRIBUTORS.txt
%{_libdir}/libcpprest.so.%{major}{,.*}

%files -n %{develname}
%license license.txt
%doc CONTRIBUTORS.txt
%{_includedir}/%{name}/
%{_includedir}/pplx/
%{_libdir}/libcpprest.so
%{_libdir}/cmake/cpprestsdk/
%{_libdir}/pkgconfig/%{name}.pc


%changelog
* Mon Jan 04 2021 daviddavid <daviddavid> 2.10.17-1.mga8
+ Revision: 1668543
- new version: 2.10.17

* Sun Apr 26 2020 daviddavid <daviddavid> 2.10.16-1.mga8
+ Revision: 1572186
- new version: 2.10.16

* Tue Feb 25 2020 daviddavid <daviddavid> 2.10.15-1.mga8
+ Revision: 1550201
- new version: 2.10.15

* Thu Feb 20 2020 umeabot <umeabot> 2.10.14-3.mga8
+ Revision: 1545439
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 2.10.14-2.mga8
+ Revision: 1483352
- rebuild for boost 1.72.0
- build with new cmake macros

* Wed Jul 17 2019 daviddavid <daviddavid> 2.10.14-1.mga8
+ Revision: 1422103
- new version: 2.10.14

* Sat Jun 29 2019 daviddavid <daviddavid> 2.10.13-1.mga8
+ Revision: 1415885
- new version: 2.10.13

* Fri Mar 29 2019 daviddavid <daviddavid> 2.10.12-1.mga7
+ Revision: 1381035
- new version: 2.10.12

* Thu Mar 21 2019 daviddavid <daviddavid> 2.10.11-1.mga7
+ Revision: 1379381
- new version: 2.10.11

* Mon Feb 04 2019 daviddavid <daviddavid> 2.10.10-1.mga7
+ Revision: 1363020
- new versiopn: 2.10.10

* Tue Jan 22 2019 daviddavid <daviddavid> 2.10.9-1.mga7
+ Revision: 1359291
- new version: 2.10.9

* Thu Nov 15 2018 daviddavid <daviddavid> 2.10.8-2.mga7
+ Revision: 1330042
- Enable brotli HTTP compression
  * add BR: pkgconfig(libbrotlidec), pkgconfig(libbrotlienc)
  * add -DCPPREST_EXCLUDE_BROTLI=OFF to cmake

* Thu Nov 15 2018 daviddavid <daviddavid> 2.10.8-1.mga7
+ Revision: 1329977
- new version: 2.10.8

* Thu Nov 01 2018 daviddavid <daviddavid> 2.10.7-1.mga7
+ Revision: 1327059
- new version: 2.10.7

* Tue Oct 16 2018 wally <wally> 2.10.6-2.mga7
+ Revision: 1321020
- rebuild for new boost 1.68.0

* Wed Sep 12 2018 daviddavid <daviddavid> 2.10.6-1.mga7
+ Revision: 1258539
- new version: 2.10.6

* Sat Aug 18 2018 daviddavid <daviddavid> 2.10.5-1.mga7
+ Revision: 1252412
- new version: 2.10.5

* Sat Aug 04 2018 daviddavid <daviddavid> 2.10.3-2.mga7
+ Revision: 1247202
- new version: 2.10.3

* Wed Jul 25 2018 daviddavid <daviddavid> 2.10.2-1.mga7
+ Revision: 1245175
- initial package cpprest

